+++
title = "Title with lots of ` ` ` backticks` `foo bar ~ zoomba"
tags = ["title"]
draft = false
+++

-   All equal/tilde characters meant for Org `~code~` or `=verbatim=`
    markup are removed.
-   The rest of the equal/tilde characters are retained.
